@@ -36,6 +36,7 @@ More instance operations:
    :toctree:
 
    close
+   delete
    info
    set_storage
 
@@ -58,18 +59,21 @@ Dev API
    Storage
 """
 
-__version__ = "0.28.1"
+__version__ = "0.30.1"  # denote a pre-release for 0.1.0 with 0.1a1
 import atexit
 from os import name as _os_name
 
+from ._close import close  # noqa
+from ._delete import delete  # noqa
 from ._info import info  # noqa
+from ._init_instance import init  # noqa
+from ._load_instance import load  # noqa
 from ._migrations import migrate
 from ._schema import schema  # noqa
 from ._set import set_storage  # noqa
 from ._settings import settings  # noqa
 from ._settings_instance import InstanceSettings, Storage  # noqa
 from ._settings_user import UserSettings  # noqa
-from ._setup_instance import close, init, load  # noqa
 from ._setup_user import login, signup  # noqa
 
 
